<p align="center">
  <img src="logo.png" />
</p>

[![Pytest](https://github.com/jiwidi/recsys/actions/workflows/pytest.yml/badge.svg)](https://github.com/jiwidi/recsys/actions/workflows/pytest.yml)
[![Pylint autoflake, isort, black](https://github.com/jiwidi/recsys/actions/workflows/linting.yml/badge.svg)](https://github.com/jiwidi/recsys/actions/workflows/linting.yml)
[![Hits](https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https%3A%2F%2Fgithub.com%2Fjiwidi%2Frecsys&count_bg=%2379C83D&title_bg=%23555555&icon=&icon_color=%23E7E7E7&title=hits&edge_flat=false)](https://hits.seeyoufarm.com)

# An open source neural recommender library

TODO: Write description of functionalities covered and create diagram image of different components.

# Install
Install latest release from pypi with:
`pip install recsys`

# Testing
To run the library test run `pytest` from the main directory

# Developing
If you want to develop on top of the recsys library you can install it in editable mode:
```
cd {recsys folder}
python -m pip install -e .
```
